/** 
 * @file stk11xx-sysfs.c
 * @author Nicolas VIVIEN
 * @date 2006-10-23
 * @version v0.0.1
 *
 * @brief Driver for Syntek USB video camera
 *
 * @note Copyright (C) Nicolas VIVIEN
 *
 * @par Licences
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * @par SubVersion
 *   $Date: 2007-01-30 19:03:56 +0100 (wto, 30 sty 2007) $
 *   $Revision: 23 $
 *   $Author: nicklas79 $
 *   $HeadURL: https://syntekdriver.svn.sourceforge.net/svnroot/syntekdriver/trunk/driver/stk11xx-sysfs.c $
 */

#include <linux/module.h>
#include <linux/init.h>
#include <linux/kernel.h>
#include <linux/errno.h>
#include <linux/slab.h>
#include <linux/kref.h>
#include <linux/device.h>

#include <linux/usb.h>
#include <linux/videodev2.h>
#include <media/v4l2-common.h>

#include "stk11xx.h"


/** 
 * @param class Class device
 *
 * @retval buf Adress of buffer with the 'release' value
 * 
 * @returns Size of buffer
 *
 * @brief show_release
 */
static ssize_t show_release(struct class_device *class, char *buf)
{
	struct video_device *vdev = to_video_device(class);
	struct usb_stk11xx *dev = video_get_drvdata(vdev);

	return sprintf(buf, "%d\n", dev->release);
}


/** 
 * @param class Class device
 *
 * @retval buf Adress of buffer with the 'brightness' value
 * 
 * @returns Size of buffer
 *
 * @brief show_brightness
 */
static ssize_t show_brightness(struct class_device *class, char *buf)
{
	struct video_device *vdev = to_video_device(class);
	struct usb_stk11xx *dev = video_get_drvdata(vdev);

	return sprintf(buf, "%X\n", dev->vsettings.brightness);
}


/** 
 * @param class Class device
 *
 * @retval buf Adress of buffer with the 'contrast' value
 * 
 * @returns Size of buffer
 *
 * @brief show_contrast
 */
static ssize_t show_contrast(struct class_device *class, char *buf)
{
	struct video_device *vdev = to_video_device(class);
	struct usb_stk11xx *dev = video_get_drvdata(vdev);

	return sprintf(buf, "%X\n", dev->vsettings.contrast);
}


/** 
 * @param class Class device
 *
 * @retval buf Adress of buffer with the 'whitebalance' value
 * 
 * @returns Size of buffer
 *
 * @brief show_whitebalance
 */
static ssize_t show_whitebalance(struct class_device *class, char *buf)
{
	struct video_device *vdev = to_video_device(class);
	struct usb_stk11xx *dev = video_get_drvdata(vdev);

	return sprintf(buf, "%X\n", dev->vsettings.whiteness);
}


static CLASS_DEVICE_ATTR(release, S_IRUGO, show_release, NULL);
static CLASS_DEVICE_ATTR(brightness, S_IRUGO, show_brightness, NULL);
static CLASS_DEVICE_ATTR(contrast, S_IRUGO, show_contrast, NULL);
static CLASS_DEVICE_ATTR(whitebalance, S_IRUGO, show_whitebalance, NULL);


/** 
 * @param vdev Video device structure
 * 
 * @returns 0 if all is OK
 *
 * @brief Create the 'sys' entries.
 *
 * This function permits to create all the entries in the 'sys' filesystem.
 */
int stk11xx_create_sysfs_files(struct video_device *vdev)
{
	int ret;

	ret = video_device_create_file(vdev, &class_device_attr_release);
	ret = video_device_create_file(vdev, &class_device_attr_brightness);
	ret = video_device_create_file(vdev, &class_device_attr_contrast);
	ret = video_device_create_file(vdev, &class_device_attr_whitebalance);

	return ret;
}


/** 
 * @param vdev Video device structure
 * 
 * @returns 0 if all is OK
 *
 * @brief Remove the 'sys' entries.
 *
 * This function permits to remove all the entries in the 'sys' filesystem.
 */
void stk11xx_remove_sysfs_files(struct video_device *vdev)
{
	video_device_remove_file(vdev, &class_device_attr_release);
	video_device_remove_file(vdev, &class_device_attr_brightness);
	video_device_remove_file(vdev, &class_device_attr_contrast);
	video_device_remove_file(vdev, &class_device_attr_whitebalance);
}

